@@ -1571,8 +1571,7 @@ int main( int argc, char * argv[] )
 
     out << "# Form implementation generated from reading ui file '" << fileName << "'" << endl;
     out << "#" << endl;
-    out << "# Created: " << TQDateTime::currentDateTime().toString() << endl;
-    out << "#      by: The Python User Interface Compiler (pyuic) " << PYTQT_VERSION << endl;
+    out << "# Created by: The Python User Interface Compiler (pyuic) " << PYTQT_VERSION << endl;
     out << "#" << endl;
     out << "# WARNING! All changes made in this file will be lost!" << endl;
     out << endl;
